[Scummvm-cvs-logs] CVS: scummvm/common system.h,1.22,1.23

Jonathan Gray khalek at users.sourceforge.net
Fri Mar 7 22:54:04 CET 2003


Update of /cvsroot/scummvm/scummvm/common
In directory sc8-pr-cvs1:/tmp/cvs-serv21758

Modified Files:
	system.h 
Log Message:
change RBG to RGB which follows the argument order and hence makes more sense...

Index: system.h
===================================================================
RCS file: /cvsroot/scummvm/scummvm/common/system.h,v
retrieving revision 1.22
retrieving revision 1.23
diff -u -d -r1.22 -r1.23
--- system.h	6 Mar 2003 21:45:29 -0000	1.22
+++ system.h	8 Mar 2003 06:53:10 -0000	1.23
@@ -180,12 +180,12 @@
 	virtual int16 get_height() {return 200;}
 	virtual int16 get_width() {return 320;}
 
 	// Methods that convert RBG to/from colors suitable for the overlay.
 	// Default implementation assumes 565 mode.
-	virtual int16 RBGToColor(uint8 r, uint8 g, uint8 b) {
+	virtual int16 RGBToColor(uint8 r, uint8 g, uint8 b) {
 		return ((((r >> 3) & 0x1F) << 11) | (((g >> 2) & 0x3F) << 5) | ((b >> 3) & 0x1F));
 	}
-	virtual void colorToRBG(int16 color, uint8 &r, uint8 &g, uint8 &b) {
+	virtual void colorToRGB(int16 color, uint8 &r, uint8 &g, uint8 &b) {
 		r = (((color >> 11) & 0x1F) << 3);
 		g = (((color >> 5) & 0x3F) << 2);
 		b = ((color&0x1F) << 3);
@@ -180,12 +180,12 @@
 	virtual int16 get_width() {return 320;}
 
-	// Methods that convert RBG to/from colors suitable for the overlay.
+	// Methods that convert RGB to/from colors suitable for the overlay.
 	// Default implementation assumes 565 mode.





More information about the Scummvm-git-logs mailing list